@@ -1,129 +1,26 @@
 package Pod::WikiDoc;
 use strict;
 use warnings;
-use vars qw($VERSION );
-$VERSION     = '0.18';
+# ABSTRACT: Generate Pod from inline wiki style text
+our $VERSION = '0.19'; # VERSION
+
+$Pod::WikiDoc::VERSION ||= '999';
 
 use 5.006;
 use Carp;
-use IO::String;
-use Scalar::Util qw( blessed );
+use IO::String 1.06;
+use Scalar::Util 1.02 qw( blessed );
 use Pod::WikiDoc::Parser;
 
 #--------------------------------------------------------------------------#
 # PREAMBLE DOCUMENTATION
 #--------------------------------------------------------------------------#
 
-=begin wikidoc
-
-= NAME
-
-Pod::WikiDoc - Generate Pod from inline wiki style text 
-
-= VERSION
-
-This documentation refers to version %%VERSION%%.
-
-= SYNOPSIS
-
-In a source file, Pod format-block style:
-    =begin wikidoc
-
-    = POD FORMAT-BLOCK STYLE
-    
-    Write documentation with *bold*, ~italic~ or {code}
-    markup.  Create a link to [Pod::WikiDoc].
-    Substitute for user-defined %%KEYWORD%%.
-
-        Indent for verbatim paragraphs
-
-    * bullet
-    * point
-    * list
-
-    0 sequentially
-    0 numbered
-    0 list
-
-    = end wikidoc
-    
-In a source file, wikidoc comment-block style:
-    ### = WIKIDOC COMMENT-BLOCK STYLE
-    ###
-    ### Optionally, [Pod::WikiDoc] can extract from
-    ### specially-marked comment blocks
-
-Generate Pod from wikidoc, programmatically:
-    use Pod::WikiDoc;
-    my $parser = Pod::WikiDoc->new( { 
-        comment_blocks => 1,
-        keywords => { KEYWORD => "foo" },
-    } );
-    $parser->filter( 
-        { input => "my_module.pm", output => "my_module.pod" }
-    );
-
-Generate Pod from wikidoc, via command line:
-    $ wikidoc -c my_module.pm my_module.pod
-    
-= DESCRIPTION
-
-Pod works well, but writing it can be time-consuming and tedious.  For example,
-commonly used layouts like lists require numerous lines of text to make just
-a couple of simple points.  An alternative approach is to write documentation
-in a wiki-text shorthand (referred to here as ~wikidoc~) and use Pod::WikiDoc
-to extract it and convert it into its corresponding Pod as a separate {.pod}
-file.
-
-Documentation written in wikidoc may be embedded in Pod format blocks, or,
-optionally, in specially marked comment blocks.  Wikidoc uses simple text-based
-markup like wiki websites to indicate formatting and links.  (See 
-[/WIKIDOC MARKUP], below.)
-
-Pod::WikiDoc processes text files (or text strings) by extracting both
-existing Pod and wikidoc, converting the wikidoc to Pod, and then writing
-the combined document back to a file or standard output. 
-
-Summary of major features of Pod::WikiDoc:
-
-* Extracts and converts wikidoc from Pod format blocks or special 
-wikidoc comment blocks
-* Extracts and preserves existing Pod
-* Provides bold, italic, code, and link markup
-* Substitutes user-defined keywords
-* Automatically converts special symbols in wikidoc to their
-Pod escape equivalents, e.g. \E\<lt\>, \E\<gt\>
-* Preserves other Pod escape sequences, e.g. \E\<euro\>
-
-In addition, Pod::WikiDoc provides a command-line utility, [wikidoc],
-to simplify wikidoc translation.
-
-See the [Pod::WikiDoc::Cookbook] for more detailed usage examples, 
-including how to automate {.pod} generation when using [Module::Build].
-
-= INTERFACE
-
-=end wikidoc
-
-=cut
 
 #--------------------------------------------------------------------------#
 # PUBLIC METHODS
 #--------------------------------------------------------------------------#
 
-### == {new}
-### 
-###     $parser = Pod::WikiDoc->new( \%args );
-### 
-### Constructor for a new Pod::WikiDoc object.  It takes a single, optional 
-### argument: a hash reference with the following optional keys:
-###
-### * {comment_blocks}: if true, Pod::WikiDoc will scan for wikidoc in comment
-### blocks.  Default is false.
-### * {comment_prefix_length}: the number of leading sharp (#) symbols to 
-### denote a comment block.  Default is 3.
-### * {keywords}: a hash reference with keywords and values for keyword
-### substitution
 
 my %default_args = (
     comment_blocks         => 0,
@@ -139,7 +36,7 @@ sub new {
 
     croak "Error: Argument to new() must be a hash reference"
         if $args && ref $args ne 'HASH';
-        
+
     my $self = { %default_args };
 
     # pick up any specified arguments;
@@ -149,53 +46,30 @@ sub new {
         }
     }
 
-    # load up a parser 
+    # load up a parser
     $self->{parser} = Pod::WikiDoc::Parser->new();
-    
+
     return bless $self, $class;
 }
 
-### == {convert}
-### 
-###     my $pod_text = $parser->convert( $input_text );
-### 
-### Given a string with valid Pod and/or wikidoc markup, filter/translate it to
-### Pod.  This is really just a wrapper around {filter} for working with
-### strings rather than files, and provides similar behavior, including adding
-### a 'Generated by' header.
 
 sub convert {
     my ($self, $input_string) = @_;
 
     croak "Error: Argument to convert() must be a scalar"
         if ( ref \$input_string ne 'SCALAR' );
-        
+
     my $input_fh = IO::String->new( $input_string );
     my $output_fh = IO::String->new();
     _filter_podfile( $self, $input_fh, $output_fh );
-    
+
     return ${ $output_fh->string_ref() };
 }
 
-### == {filter}
-### 
-###     $parser->filter( \%args );
-### 
-### Filters from an input file for Pod and wikidoc, translating it to Pod 
-### and writing it to an output file.  The output file will be prefixed with
-### a 'Generated by' comment with the version of Pod::WikiDoc and timestamp,
-### as required by [perlpodspec].
-###
-### {filter} takes a single, optional argument: a hash reference with 
-### the following optional keys:
-###
-### * {input}: a filename or filehandle to read from. Defaults to STDIN.  
-### * {output}: a filename or filehandle to write to.  If given a filename
-### and the file already exists, it will be clobbered. Defaults to STDOUT.
 
 sub filter {
     my ( $self, $args_ref ) = @_;
-    
+
     croak "Error: Argument to filter() must be a hash reference"
         if defined $args_ref && ref($args_ref) ne 'HASH';
     # setup input
@@ -204,11 +78,11 @@ sub filter {
         $input_fh = \*STDIN;
     }
     elsif ( ( blessed $args_ref->{input} && $args_ref->{input}->isa('GLOB') )
-         || ( ref $args_ref->{input}  eq 'GLOB' ) 
+         || ( ref $args_ref->{input}  eq 'GLOB' )
          || ( ref \$args_ref->{input} eq 'GLOB' ) ) {
         # filehandle or equivalent
         $input_fh = $args_ref->{input};
-    } 
+    }
     elsif ( ref \$args_ref->{input} eq 'SCALAR' ) {
         # filename
         open( $input_fh, "<", $args_ref->{input} )
@@ -217,18 +91,18 @@ sub filter {
     else {
         croak "Error: 'input' parameter for filter() must be a filename or filehandle"
     }
-    
+
     # setup output
     my $output_fh;
     if ( ! $args_ref->{output} ) {
         $output_fh = \*STDOUT;
     }
     elsif ( ( blessed $args_ref->{output} && $args_ref->{output}->isa('GLOB') )
-         || ( ref $args_ref->{output}  eq 'GLOB' ) 
+         || ( ref $args_ref->{output}  eq 'GLOB' )
          || ( ref \$args_ref->{output} eq 'GLOB' ) ) {
         # filehandle or equivalent
         $output_fh = $args_ref->{output};
-    } 
+    }
     elsif ( ref \$args_ref->{output} eq 'SCALAR' ) {
         # filename
         open( $output_fh, ">", $args_ref->{output} )
@@ -237,28 +111,18 @@ sub filter {
     else {
         croak "Error: 'output' parameter for filter() must be a filename or filehandle"
     }
-    
+
     _filter_podfile( $self, $input_fh, $output_fh );
     return;
 }
 
-### == {format}
-###
-###     my $pod_text = $parser->format( $wiki_text );
-### 
-### Given a string with valid Pod and/or wikidoc markup, filter/translate it to
-### Pod. Unlike {convert}, no 'Generated by' comment is added.  This 
-### function is used internally by Pod::WikiDoc, but is being made available
-### as a public method for users who want more granular control of the 
-### translation process or who want to convert wikidoc to Pod for other
-### creative purposes using the Pod::WikiDoc engine.
 
 sub format { ## no critic
     my ($self, $wikitext) = @_;
-    
+
     croak "Error: Argument to format() must be a scalar"
         if ( ref \$wikitext ne 'SCALAR' );
-        
+
     my $wiki_tree  = $self->{parser}->WikiDoc( $wikitext ) ;
     for my $node ( @$wiki_tree ) {
         undef $node if ! ref $node;
@@ -326,7 +190,7 @@ sub _exhaust_iterator {
 # _output_iterator
 #
 # returns an output "iterator" that streams to a filehandle.  Inputs
-# are array refs of the form [ $FORMAT, @LINES ].  Format 'pod' is 
+# are array refs of the form [ $FORMAT, @LINES ].  Format 'pod' is
 # printed to the filehandle immediately.  Format 'wikidoc' is accumulated
 # until the next 'pod' then converted to wikidoc and printed to the file
 # handle
@@ -343,7 +207,7 @@ sub _output_iterator {
             return;
         }
         return unless ref($chunk) eq 'ARRAY';
-        my ($format, @lines) = @$chunk;
+        my ($format, @lines) = grep { defined $_ } @$chunk;
         if ( $format eq 'wikidoc' ) {
             push @wikidoc, @lines;
         }
@@ -357,7 +221,7 @@ sub _output_iterator {
 }
 
 #--------------------------------------------------------------------------#
-# _filter_podfile() 
+# _filter_podfile()
 #
 # extract Pod from input and pass through to output, converting any wikidoc
 # markup to Pod in the process
@@ -378,9 +242,9 @@ sub _filter_podfile {
 
     # open output with tag and Pod marker
     print $output_fh
-          "# Generated by Pod::WikiDoc version $VERSION\n\n";
+          "# Generated by Pod::WikiDoc version $Pod::WikiDoc::VERSION\n\n";
     print $output_fh "=pod\n\n";
-    
+
     # setup iterators
     my $in_iter = $self->_input_iterator( $input_fh );
     my $out_iter = $self->_output_iterator( $output_fh );
@@ -395,11 +259,11 @@ sub _filter_podfile {
 #--------------------------------------------------------------------------#
 # _filter_code
 #
-# we need a "cutting" flag -- if we got here from a =cut, then we return to 
+# we need a "cutting" flag -- if we got here from a =cut, then we return to
 # caller ( pod or format ) when we see pod. Otherwise we're just starting
 # and need to start a new pod filter when we see pod
 #
-# perlpodspec says starting Pod with =cut is an error and that we 
+# perlpodspec says starting Pod with =cut is an error and that we
 # *must* halt parsing and *should* issue a warning. Here we might be
 # far down the call stack and don't want to just return where the caller
 # might continue processing.  To avoid this, we exhaust the input first.
@@ -431,7 +295,7 @@ sub _filter_code {
 #--------------------------------------------------------------------------#
 # _filter_pod
 #
-# Pass through lines to the output iterators, but flag wikidoc lines 
+# Pass through lines to the output iterators, but flag wikidoc lines
 # differently so that they can be converted on output
 #
 # If we find an =end that is out of order, perlpodspec says we *must* warn
@@ -448,7 +312,7 @@ sub _filter_pod {
             $in_iter->('drop');
             next LINE;
         };
-        $peek =~ $CUT && do { 
+        $peek =~ $CUT && do {
             $in_iter->('drop');
             $self->_filter_code( $in_iter, $out_iter, 1 );
             next LINE;
@@ -489,10 +353,10 @@ sub _filter_pod {
                 # and let it fall through to the output iterator
             }
         };
-        do { 
-            my $out_type = 
-                ( @format && $format[-1] eq 'wikidoc' ) ? 'wikidoc' : 'pod' ; 
-            $out_iter->( [ $out_type, $in_iter->('next') ] ) 
+        do {
+            my $out_type =
+                ( @format && $format[-1] eq 'wikidoc' ) ? 'wikidoc' : 'pod' ;
+            $out_iter->( [ $out_type, $in_iter->('next') ] )
         };
     }
     return;
@@ -524,8 +388,8 @@ sub _filter_for {
     else {
         push @lines, $in_iter->('next');
     }
-    my $out_type =  $format eq 'wikidoc' ? 'wikidoc' : 'pod' ; 
-    $out_iter->( [ $out_type, @lines ] ); 
+    my $out_type =  $format eq 'wikidoc' ? 'wikidoc' : 'pod' ;
+    $out_iter->( [ $out_type, @lines ] );
     return;
 }
 
@@ -566,16 +430,16 @@ my %opening_of = (
     Unordered_List      =>  "=over\n\n",
     Ordered_List        =>  sub { $numbered_bullet = 1; return "=over\n\n" },
     Preformat           =>  q{},
-    Header              =>  sub { 
-                                my $node = shift; 
-                                my $level = $node->{level} > 4 
+    Header              =>  sub {
+                                my $node = shift;
+                                my $level = $node->{level} > 4
                                     ? 4 : $node->{level};
                                 return "=head$level "
                             },
     Bullet_Item         =>  "=item *\n\n",
-    Numbered_Item       =>  sub { 
-                                return  "=item " . $numbered_bullet++ 
-                                        . ".\n\n" 
+    Numbered_Item       =>  sub {
+                                return  "=item " . $numbered_bullet++
+                                        . ".\n\n"
                             },
     Indented_Line       =>  q{ },
     Plain_Line          =>  q{},
@@ -622,7 +486,7 @@ my %closing_of = (
 # Subroutine to handle actual raw content from different node types
 # from the parse tree
 my %content_handler_for = (
-    RegularText         =>  \&_escape_pod, 
+    RegularText         =>  \&_escape_pod,
     Empty_Line          =>  sub { q{} },
     KeyWord             =>  \&_keyword_expansion,
 );
@@ -646,21 +510,21 @@ my $specials = join q{}, keys %escape_code_for;
 #
 #--------------------------------------------------------------------------#
 
-sub _escape_pod { 
-    
-    my $node = shift; 
-    
-    my $input_text  = $node->{content};
-    
-    # remove backslash escaping
-    $input_text =~ s{ \\(.) } 
-                    {$1}gxms;
-    
-    # replace special symbols with corresponding escape code
-    $input_text =~ s{ ( [$specials] ) } 
-                    {$escape_code_for{$1}}gxms; 
+sub _escape_pod {
 
-    return $input_text; 
+    my $node = shift;
+
+    my $input_text  = $node->{content};
+
+    # remove backslash escaping
+    $input_text =~ s{ \\(.) }
+                    {$1}gxms;
+
+    # replace special symbols with corresponding escape code
+    $input_text =~ s{ ( [$specials] ) }
+                    {$escape_code_for{$1}}gxms;
+
+    return $input_text;
 }
 
 #--------------------------------------------------------------------------#
@@ -677,7 +541,7 @@ sub _keyword_expansion {
     return defined $value ? $value : q{%%} . $key . q{%%} ;
 }
 
-    
+
 #--------------------------------------------------------------------------#
 # _translate_wikidoc()
 #
@@ -707,15 +571,15 @@ sub _wiki2pod {
 
         $result .= ref $opening eq 'CODE' ? $opening->($node) : $opening;
         if ( ref $node->{content} eq 'ARRAY' ) {
-            $result .= _wiki2pod( 
-                $node->{content}, 
+            $result .= _wiki2pod(
+                $node->{content},
                 $keywords,
-                $node->{type} eq 'Preformat' ? 1 : 0 
+                $node->{type} eq 'Preformat' ? 1 : 0
             );
         }
         else {
             my $handler = $content_handler_for{ $node->{type} };
-            $result .= defined $handler 
+            $result .= defined $handler
                      ? $handler->( $node, $keywords ) : $node->{content}
             ;
         }
@@ -725,198 +589,464 @@ sub _wiki2pod {
 }
 
 1; #this line is important and will help the module return a true value
-__END__
 
-=begin wikidoc
 
-= WIKIDOC MARKUP
+=pod
+
+=head1 NAME
+
+Pod::WikiDoc - Generate Pod from inline wiki style text
+
+=head1 VERSION
+
+version 0.19
+
+=head1 SYNOPSIS
+
+In a source file, Pod format-block style:
+
+     =begin wikidoc
+ 
+     = POD FORMAT-BLOCK STYLE
+ 
+     Write documentation with *bold*, ~italic~ or {code}
+     markup.  Create a link to [Pod::WikiDoc].
+     Substitute for user-defined %%KEYWORD%%.
+ 
+         Indent for verbatim paragraphs
+ 
+     * bullet
+     * point
+     * list
+ 
+     0 sequentially
+     0 numbered
+     0 list
+ 
+     =end wikidoc
+
+In a source file, wikidoc comment-block style:
+
+     ### = WIKIDOC COMMENT-BLOCK STYLE
+     ###
+     ### Optionally, [Pod::WikiDoc] can extract from
+     ### specially-marked comment blocks
+
+Generate Pod from wikidoc, programmatically:
+
+     use Pod::WikiDoc;
+     my $parser = Pod::WikiDoc->new( {
+         comment_blocks => 1,
+         keywords => { KEYWORD => "foo" },
+     } );
+     $parser->filter(
+         { input => "my_module.pm", output => "my_module.pod" }
+     );
+
+Generate Pod from wikidoc, via command line:
+
+     $ wikidoc -c my_module.pm my_module.pod
+
+=head1 DESCRIPTION
+
+Pod works well, but writing it can be time-consuming and tedious.  For example,
+commonly used layouts like lists require numerous lines of text to make just
+a couple of simple points.  An alternative approach is to write documentation
+in a wiki-text shorthand (referred to here as I<wikidoc>) and use Pod::WikiDoc
+to extract it and convert it into its corresponding Pod as a separate C<<< .pod >>>
+file.
+
+Documentation written in wikidoc may be embedded in Pod format blocks, or,
+optionally, in specially marked comment blocks.  Wikidoc uses simple text-based
+markup like wiki websites to indicate formatting and links.  (See
+L</WIKIDOC MARKUP>, below.)
+
+Pod::WikiDoc processes text files (or text strings) by extracting both
+existing Pod and wikidoc, converting the wikidoc to Pod, and then writing
+the combined document back to a file or standard output.
+
+Summary of major features of Pod::WikiDoc:
+
+=over
+
+=item *
+
+Extracts and converts wikidoc from Pod format blocks or special
+wikidoc comment blocks
+
+=item *
+
+Extracts and preserves existing Pod
+
+=item *
+
+Provides bold, italic, code, and link markup
+
+=item *
+
+Substitutes user-defined keywords
+
+=item *
+
+Automatically converts special symbols in wikidoc to their
+Pod escape equivalents, e.g. EE<lt>ltE<gt>, EE<lt>gtE<gt>
+
+=item *
+
+Preserves other Pod escape sequences, e.g. EE<lt>euroE<gt>
+
+=back
+
+In addition, Pod::WikiDoc provides a command-line utility, L<wikidoc>,
+to simplify wikidoc translation.
+
+See the L<Pod::WikiDoc::Cookbook> for more detailed usage examples,
+including how to automate C<<< .pod >>> generation when using L<Module::Build>.
+
+=head1 INTERFACE
+
+=head2 C<<< new >>>
+
+     $parser = Pod::WikiDoc->new( \%args );
+
+Constructor for a new Pod::WikiDoc object.  It takes a single, optional
+argument: a hash reference with the following optional keys:
+
+=over
+
+=item *
+
+C<<< comment_blocks >>>: if true, Pod::WikiDoc will scan for wikidoc in comment
+blocks.  Default is false.
+
+=item *
+
+C<<< comment_prefix_length >>>: the number of leading sharp (#) symbols to
+denote a comment block.  Default is 3.
+
+=item *
+
+C<<< keywords >>>: a hash reference with keywords and values for keyword
+substitution
+
+=back
+
+=head2 C<<< convert >>>
+
+     my $pod_text = $parser->convert( $input_text );
+
+Given a string with valid Pod andE<sol>or wikidoc markup, filterE<sol>translate it to
+Pod.  This is really just a wrapper around C<<< filter >>> for working with
+strings rather than files, and provides similar behavior, including adding
+a 'Generated by' header.
+
+=head2 C<<< filter >>>
+
+     $parser->filter( \%args );
+
+Filters from an input file for Pod and wikidoc, translating it to Pod
+and writing it to an output file.  The output file will be prefixed with
+a 'Generated by' comment with the version of Pod::WikiDoc and timestamp,
+as required by L<perlpodspec>.
+
+C<<< filter >>> takes a single, optional argument: a hash reference with
+the following optional keys:
+
+=over
+
+=item *
+
+C<<< input >>>: a filename or filehandle to read from. Defaults to STDIN.
+
+=item *
+
+C<<< output >>>: a filename or filehandle to write to.  If given a filename
+and the file already exists, it will be clobbered. Defaults to STDOUT.
+
+=back
+
+=head2 C<<< format >>>
+
+     my $pod_text = $parser->format( $wiki_text );
+
+Given a string with valid Pod andE<sol>or wikidoc markup, filterE<sol>translate it to
+Pod. Unlike C<<< convert >>>, no 'Generated by' comment is added.  This
+function is used internally by Pod::WikiDoc, but is being made available
+as a public method for users who want more granular control of the
+translation process or who want to convert wikidoc to Pod for other
+creative purposes using the Pod::WikiDoc engine.
+
+=head1 WIKIDOC MARKUP
 
 Pod::WikiDoc uses a wiki-style text markup, called wikidoc.  It is heavily
-influenced by [Kwiki].  Like other wiki markup, it has both block and 
+influenced by L<Kwiki>.  Like other wiki markup, it has both block and
 inline elements, which map directly to their Pod equivalents.
 
 Block elements include:
-* Headers
-* Verbatim text
-* Bullet lists
-* Numbered lists
-* Ordinary paragraphs
 
-Block elements should be separated by a blank line (though Pod::WikiDoc 
+=over
+
+=item *
+
+Headers
+
+=item *
+
+Verbatim text
+
+=item *
+
+Bullet lists
+
+=item *
+
+Numbered lists
+
+=item *
+
+Ordinary paragraphs
+
+=back
+
+Block elements should be separated by a blank line (though Pod::WikiDoc
 will do the right thing in many cases if you don't).
 
 Inline elements include:
-* Bold
-* Italic
-* Code
-* Link
-* Escape code
-* Keywords
+
+=over
+
+=item *
+
+Bold
+
+=item *
+
+Italic
+
+=item *
+
+Code
+
+=item *
+
+Link
+
+=item *
+
+Escape code
+
+=item *
+
+Keywords
+
+=back
 
 All text except that found in verbatim text, code markup or keywords is
 transformed to convert special Pod characters to Pod escape code markup:
-\E\<lt\>, \E\<gt\>, \E\<sol\>, \E\<verbar\>.  Inline markup can be escaped with
-a backslash (\\).  Including a literal backslash requires a double-backslash
-(\\\\).
+EE<lt>ltE<gt>, EE<lt>gtE<gt>, EE<lt>solE<gt>, EE<lt>verbarE<gt>.  Inline markup can be escaped with
+a backslash (\).  Including a literal backslash requires a double-backslash
+(\\).
 
-== Headers
+=head2 Headers
 
 Headers are indicated with one or more equals signs followed by whitespace in
 the first column.  The number of equals signs indicates the level of the
-header (the maximum is four).  Headers can not span multiple lines.  
+header (the maximum is four).  Headers can not span multiple lines.
 
-    = header level 1
-    
-    == header level 2
+     = header level 1
+ 
+     == header level 2
 
-== Verbatim text
+=head2 Verbatim text
 
 Verbatim text is indicated with leading whitespace in each line of text,
 just as with Pod.
 
-    #<--- first column 
+     #<--- first column
+ 
+         sub verbatim {}
 
-        sub verbatim {}
-
-== Bullet lists
+=head2 Bullet lists
 
 Bullet lists are indicated with an asterisk in the first column followed by
 whitespace.  Bullet lists can span multiple lines.  Lines after the first
 should not have an asterisk or be indented.
 
-    * First item in the list
-    * Second item in the list
-    on multiple lines
-    * Third item in the list
+     * First item in the list
+     * Second item in the list
+     on multiple lines
+     * Third item in the list
 
-== Numbered lists
+=head2 Numbered lists
 
 Numbered lists work just like numbered lists, but with a leading 0 followed
 by whitespace.
 
-    0 First item in the list
-    0 Second item in the list
-    on multiple lines
-    0 Third item in the list
+     0 First item in the list
+     0 Second item in the list
+     on multiple lines
+     0 Third item in the list
 
-== Ordinary paragraphs
+=head2 Ordinary paragraphs
 
 Ordinary paragraphs consist of one or more lines of text that do not match
 the criteria of other blocks.  Paragraphs are terminated with a empty line.
 
-    This is an ordinary paragraph that
-    spans multiple lines.
+     This is an ordinary paragraph that
+     spans multiple lines.
 
-== Bold markup
+=head2 Bold markup
 
 Bold text is indicated by bracketing with asterisks.  Bold markup must
 begin at a whitespace boundary, the start of a line, or the inside of
 other markup.
 
-    This shows *bold* text.
+     This shows *bold* text.
 
-== Italic markup
+=head2 Italic markup
 
 Italic text is indicated by bracketing with tildes.  Italic markup must
 begin at a whitespace boundary, the start of a line, or the inside of
 other markup.
 
-    This shows ~italic~ text.
+     This shows ~italic~ text.
 
-== Code markup
+=head2 Code markup
 
 Code (monospaced) text is indicated by bracketing with matched braces.  Code
 markup must begin at a whitespace boundary, the start of a line, or the inside
 of other markup.  Brackets should nest properly with code.
 
-    This shows {code} text.  It can surround text
-    with brackets like this: { $data{ $id } }
+     This shows {code} text.  It can surround text
+     with brackets like this: { $data{ $id } }
 
-== Link markup
+=head2 Link markup
 
 Link text is indicated by bracketing with square brackets.  As with Pod, link
 text may include a vertical bar to separate display text from the link itself.
 Link markup must begin at a whitespace boundary, the start of a line, or the
 inside of other markup.
 
-    This is an ordinary [Pod::WikiDoc] link.
-    This is a [way to ~markup~ links|Pod::WikiDoc] with display text
-    Hypertext links look like this: [http://www.google.com/]
+     This is an ordinary [Pod::WikiDoc] link.
+     This is a [way to ~markup~ links|Pod::WikiDoc] with display text
+     Hypertext links look like this: [http://www.google.com/]
 
-== Escape code markup
+=head2 Escape code markup
 
 Pod-style escape text is passed through as normal to support international
 or other unusual characters.
 
-    This is the euro symbol: E<euro> 
+     This is the euro symbol: E<euro>
 
-== Keyword markup
+=head2 Keyword markup
 
 Text surrounded by double-percent signs is treated as a keyword for expansion.
 The entire expression will be replaced with the value of the keyword from the
-hash provided when the parser is created with {new()}.  If the keyword is
+hash provided when the parser is created with C<<< new() >>>.  If the keyword is
 unknown or the value is undefined, the keyword will be passed through
 unchanged.
 
-    This is version %%VERSION%%
+     This is version %%VERSION%%
 
-= DIAGNOSTICS
+=head1 DIAGNOSTICS
 
-* {Error: Argument to convert() must be a scalar}
-* {Error: Argument to filter() must be a hash reference}
-* {Error: Argument to format() must be a scalar}
-* {Error: Argument to new() must be a hash reference}
-* {Error: Class method new() can't be called on an object}
-* {Error: Couldn't open input file 'FILENAME'}
-* {Error: Couldn't open output file 'FILENAME'}
-* {Error: 'input' parameter for filter() must be a filename or filehandle}
-* {Error: 'output' parameter for filter() must be a filename or filehandle}
+=over
 
-= INCOMPATIBILITIES
+=item *
 
-* Default prefix length for wikidoc comment-blocks conflicts with
-[Smart::Comments].  Change the {comment_prefix_length} argument to {new} in
-Pod::WikiDoc or the level of 'smartness' in [Smart::Comments] to avoid the
+C<<< Error: Argument to convert() must be a scalar >>>
+
+=item *
+
+C<<< Error: Argument to filter() must be a hash reference >>>
+
+=item *
+
+C<<< Error: Argument to format() must be a scalar >>>
+
+=item *
+
+C<<< Error: Argument to new() must be a hash reference >>>
+
+=item *
+
+C<<< Error: Class method new() can't be called on an object >>>
+
+=item *
+
+C<<< Error: Couldn't open input file 'FILENAME' >>>
+
+=item *
+
+C<<< Error: Couldn't open output file 'FILENAME' >>>
+
+=item *
+
+C<<< Error: 'input' parameter for filter() must be a filename or filehandle >>>
+
+=item *
+
+C<<< Error: 'output' parameter for filter() must be a filename or filehandle >>>
+
+=back
+
+=head1 INCOMPATIBILITIES
+
+=over
+
+=item *
+
+Default prefix length for wikidoc comment-blocks conflicts with
+L<Smart::Comments>.  Change the C<<< comment_prefix_length >>> argument to C<<< new >>> in
+Pod::WikiDoc or the level of 'smartness' in L<Smart::Comments> to avoid the
 conflict.
 
-* Module::Build before 0.28 does not look in external {.pod} files 
-to generate a {README} with the {create_readme} option or to find a module 
-abstract.  Set the abstract manually in the {Build.PL} file with the
-{dist_abstract} option.
+=back
 
-= BUGS
+=over
 
-Please report bugs or feature requests using the CPAN Request Tracker.
-Bugs can be submitted using the web interface at
-[http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-WikiDoc]
+=item *
 
-When submitting a bug or request, please include a test-file or a patch to an
-existing test-file that illustrates the bug or desired feature.
+Module::Build before 0.28 does not look in external C<<< .pod >>> files
+to generate a C<<< README >>> with the C<<< create_readme >>> option or to find a module
+abstract.  Set the abstract manually in the C<<< Build.PL >>> file with the
+C<<< dist_abstract >>> option.
 
-= AUTHOR
+=back
 
-David A. Golden (DAGOLDEN)
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
 
-= COPYRIGHT AND LICENSE
+=head1 SUPPORT
 
-Copyright (c) 2005, 2006, 2007 by David A. Golden
+=head2 Bugs / Feature Requests
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at 
-[http://www.apache.org/licenses/LICENSE-2.0]
+Please report any bugs or feature requests through the issue tracker
+at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-WikiDoc>.
+You will be notified automatically of any progress on your issue.
 
-Files produced as output though the use of this software, including
-generated copies of boilerplate templates provided with this software,
-shall not be considered Derivative Works, but shall be considered the
-original work of the Licensor.
+=head2 Source Code
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
 
-=end wikidoc
+L<https://github.com/dagolden/pod-wikidoc>
+
+  git clone https://github.com/dagolden/pod-wikidoc.git
+
+=head1 AUTHOR
+
+David A Golden <dagolden@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by David A Golden.
+
+This is free software, licensed under:
+
+  The Apache License, Version 2.0, January 2004
 
 =cut
+
+
+__END__
+
